<?php

/**
 *
 * Hijri Calendar Extension
 *
 * @copyright (c) 2015 Saeed Hubaishan http://salafitech.net
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */
namespace hubaishan\hijri\acp;

use \hubaishan\hijri\calendarAdjustment;

/**
 *
 * @package acp
 */
class hijri_calendar_module
{
	
	/** @var \phpbb\config\config */
	protected $config;
	
	/** @var \phpbb\config_text */
	protected $config_text;
	
	/** @var \phpbb\request\request */
	protected $request;
	
	/** @var \phpbb\template\template */
	protected $template;
	
	/** @var \phpbb\user */
	protected $user;
	
	/** @var \hubaishan\hijri\calendarAdjustment */
	protected $hijri_adjs;
	
	/** @var string */
	public $u_action;
	
	/** @var string */
	protected $lang_name;

	/**
	 * Construct function
	 *
	 * @global \phpbb\config $config
	 * @global \phpbb\request $request
	 * @global \phpbb\template $template
	 * @global \phpbb\user $user
	 * @global \phpbb\config\db_text $config_text
	 * @global \phpbb\phpbb_container $phpbb_container
	 */
	public function __construct()
	{
		global $config, $request, $template, $user, $config_text, $phpbb_container;
		
		$this->config = $config;
		$this->config_text = $phpbb_container->get('config_text');
		$this->request = $request;
		$this->template = $template;
		$this->user = $user;
		$this->user->add_lang('acp/common');
		$this->user->add_lang_ext('hubaishan/hijri', 'hijri_acp');
		$this->hijri_adjs = new \hubaishan\hijri\calendarAdjustment(array(
			'umalqura' => ($this->config['hijri_umalqura'] == '1'), 
			'adj_data' => $this->config_text->get('hijri_adj_data')
		));
		
		$this->lang_name = strtok($this->user->lang_name,'-_');
	}

	/**
	 * Main ACP module
	 *
	 * @param int $id        	
	 * @param string $mode        	
	 * @access public
	 */
	public function main($id, $mode)
	{
		$this->tpl_name = 'acp_hijri_calendar';
		$this->page_title = $this->user->lang['HIJRI_CALENDAR'];
		$action = $this->request->variable('action', '');
		$month = $this->request->variable('m', 0);
		$year = $this->request->variable('y', 0);
		
		$form_key = 'acp_hijri_calendar';
		add_form_key($form_key);
		
		if ($this->request->is_set_post('submit'))
		{
			$an_error = false;
			if (!check_form_key($form_key))
			{
				trigger_error($this->user->lang['FORM_INVALID'] . adm_back_link($this->u_action), E_USER_WARNING);
			}
			if ($action == 'modify')
			{
				$month_start = $this->request->variable('month_start', 1);
				if ($month_start > 0 && $this->hijri_adjs->add_adj($month, $year, $month_start) == TRUE)
				{
					$this->config_text->set('hijri_adj_data', $this->hijri_adjs->get_adjdata(TRUE));
					//$notice = $this->user->lang['HIJRI_ADJ_MODIFIED'];
				}
				else
				{
					$an_error = true;
				}
			}
			else
			{
				$this->config->set('hijri_umalqura', $this->request->variable('hijri_umalqura', 1));
			}
			
			if ($an_error)
			{
				trigger_error($this->user->lang['HIJRI_ADJ_MODIFING_ERROR'], E_USER_WARNING);
			}
			else
			{
				trigger_error($this->user->lang['CONFIG_UPDATED'] . adm_back_link($this->u_action));
			}
		}
		else
		{
			
			switch ($action)
			{
				case 'delete' :
					if (confirm_box(true))
					{
						if ($month > 0 && $month < 13 && $year >= calendarAdjustment::umstartyear && $year <= calendarAdjustment::umendyear)
						{
							$this->hijri_adjs->del_adj($month, $year);
							$this->config_text->set('hijri_adj_data', $this->hijri_adjs->get_adjdata(TRUE));
							if ($this->request->is_ajax())
							{
								$json_response = new \phpbb\json_response();
								$json_response->send(array(
									'MESSAGE_TITLE' => $this->user->lang['INFORMATION'], 
									'MESSAGE_TEXT' => $this->user->lang['HIJRI_ADJ_DELETED'], 
									'REFRESH_DATA' => array(
										'time' => 3
									)
								));
							}
						}
					}
					else
					{
						$confirm_txt = $this->user->lang['HIJRI_DELETE_ADJ_CONFIRM'] . $this->named_month($month) . '-' . $year;
						$del_info = $this->hijri_adjs->auto_del_info($month, $year);
						if (!empty($del_info))
						{
							$confirm_txt .= '<br/>' . $this->user->lang['HIJRI_DELETE_ALSO_CONFIRM'];
							foreach ($del_info as $v)
							{
								$confirm_txt .= '<br/>' . $this->named_month($v['month']) . ' - ' . $v['year'];
							}
						}
						
						confirm_box(false, $confirm_txt, build_hidden_fields(array(
							'i' => $id, 
							'mode' => $mode, 
							'm' => $month, 
							'y' => $year, 
							'action' => 'delete'
						)));
					}
				
				break;
				
				case 'modify' :
					if ($month > 0 && $month < 13 && $year >= calendarAdjustment::umstartyear && $year <= calendarAdjustment::umendyear)
					{
						$start_options = $this->hijri_adjs->get_possible_starts($month, $year);
						$options_txt = '';
						
						foreach ($start_options as $start_option)
						{
							$options_txt .= '<option value="' . $start_option['jd'] . '" ' . ($start_option['currentset'] ? ' selected ' : '') . '>' . $this->format_grdate($start_option['grdate']);
							foreach ($start_option['alsoadjdata'] as $v)
							{
								
								$options_txt .= ' ' . sprintf($this->user->lang['HIJRI_AND_ALSO_WILL_ADJ'], $this->named_month($v['month']), $v['year'], $this->format_grdate($v['grdate']));
							}
							$options_txt .= "</option>\n";
						}
						
						$this->template->assign_vars(array(
							'L_MONTH_START_MODIFY' => $this->user->lang['HIJRI_MODIFY_MONTH_START'] . ' ' . $this->named_month($month) . '-' . $year, 
							'S_MONTH' => $month, 
							'S_YEAR' => $year, 
							'S_MONTH_OPTIONS' => $options_txt, 
							'U_ACTION' => $this->u_action, 
							'S_ADD' => TRUE
						));
					}
				break;
				
				default :
					$adjs = $this->hijri_adjs->get_current_adjs();
					foreach ($adjs as $v)
					{
						$this->template->assign_block_vars('adjs', array(
							'ADJ_TIT' => $v['year'] . ' - ' . $this->named_month($v['month']), 
							'ADJ_CUR' => $this->format_grdate($v['current']), 
							'ADJ_ORG' => $this->format_grdate($v['default']), 
							'U_EDIT' => $this->u_action . '&amp;action=modify&amp;m=' . $v['month'] . '&amp;y=' . $v['year'], 
							'U_DELETE' => $this->u_action . '&amp;action=delete&amp;m=' . $v['month'] . '&amp;y=' . $v['year']
						));
					}
					
					// build OPTIONS_YEARS
					$option_years = '';
					$dt = new \hubaishan\hijri\datetime($this->user);
					list($current_year, $current_month, $current_day) = explode('-', $dt->format('_Y-_n-_j'));
					if ($current_day > 20)
					{
						$current_month++;
						if ($current_month == 13)
						{
							$current_year++;
							$current_month = 1;
						}
					}
					for ($n = calendarAdjustment::umstartyear; $n <= calendarAdjustment::umendyear; $n++)
					{
						$selected = ($n == $current_year) ? 'selected' : '';
						$option_years .= "<option value='$n' $selected>$n</option>\n";
					}
					// build OPTIONS_MONTHS
					$option_months = '';
					for ($n = 1; $n < 13; $n++)
					{
						$selected = ($n == ($current_month)) ? 'selected' : '';
						$option_months .= "<option value='$n' $selected>$n-" . $this->user->lang['HIJRI_MONTHS'][$n] . "</option>\n";
					}
					$this->template->assign_vars(array(
						'S_HIJRI_UMALQURA' => $this->config['hijri_umalqura'], 
						'U_ACTION' => $this->u_action, 
						'OPTIONS_YEARS' => $option_years, 
						'OPTIONS_MONTHS' => $option_months, 
						'DEFAULT_HREF' => $this->u_action . '&amp;action=modify&amp;m=' . $current_month . '&amp;y=' . $current_year, 
						'U_ACTION_JS' => str_replace('&amp;', '&', $this->u_action)
					));
			}
		}
	}

	/**
	 * return formated month name
	 * 
	 * @param int $month_num        	
	 * @return string formated month name
	 */
	private function named_month($month_num)
	{
		return $this->user->lang['HIJRI_MONTHS'][$month_num] . '(' . $month_num . ')';
	}

	/**
	 * return formated gregorian date
	 * 
	 * @param mixed $grdate
	 *        	date value accepted by datetime class
	 * @return string formated gregorian date
	 */
	private function format_grdate($grdate)
	{
		$dt = $this->user->create_datetime($grdate);
		return $dt->format($this->user->lang['DATE_FORMAT'], TRUE);
	}
}
