<?php

/**
 *
 * This file is part of hijri calendar exstension
 *
 * @copyright (c) Saeed Hubaishan <http://www.salafitech.net>
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 *
 */
namespace hubaishan\hijri;

class ext extends \phpbb\extension\base
{

	/**
	 * Require 3.1.8 due to expanded dateformat field
	 */
	public function is_enableable()
	{
		$config = $this->container->get('config');
		return phpbb_version_compare($config['version'], '3.1.8-RC1', '>=');
	}

	/**
	 *
	 * @param mixed $old_state
	 *        	State returned by previous call of this method
	 * @return mixed Returns false after last step, otherwise temporary state
	 * @access public
	 */
	public function enable_step($old_state)
	{
		switch ($old_state)
		{
			case '' :
				
				$this->restore_dateformat();
				return 'restore_dateformat';
			
			break;
			
			default :
				
				// Run parent enable step method
				return parent::enable_step($old_state);
			
			break;
		}
	}

	/**
	 *
	 * @param mixed $old_state
	 *        	State returned by previous call of this method
	 * @return mixed Returns false after last step, otherwise temporary state
	 * @access public
	 */
	public function disable_step($old_state)
	{
		switch ($old_state)
		{
			case '' : // Empty means nothing has run yet
				
				$this->backup_dateformat();
				$this->rest_dateformat();
				return 'backup_dateformat';
			
			break;
			
			default :
				
				// Run parent disable step method
				return parent::disable_step($old_state);
			
			break;
		}
	}

	/**
	 *
	 * @param mixed $old_state
	 *        	State returned by previous call of this method
	 * @return mixed Returns false after last step, otherwise temporary state
	 * @access public
	 */
	public function purge_step($old_state)
	{
		switch ($old_state)
		{
			case '' : // Empty means nothing has run yet
			          
				// Purge
				$this->rest_dateformat();
				return 'rest_dateformat';
			
			break;
			
			default :
				
				// Run parent purge step method
				return parent::purge_step($old_state);
			
			break;
		}
	}

	private function backup_dateformat()
	{
		global $db;
		$config_text = $this->container->get('config_text');
		$config = $this->container->get('config');
		$sql = 'UPDATE ' . USERS_TABLE . ' SET hijri_dateformat_bk=user_dateformat WHERE user_dateformat ' . $db->sql_like_expression($db->get_any_char() . '_' . $db->get_any_char());
		$db->sql_query($sql);
		$config_text->set('hijri_default_dateformat_bk', $config['default_dateformat']);
	}

	private function rest_dateformat()
	{
		global $db;
		$config = $this->container->get('config');
		$user = $this->container->get('user');
		if (strpos($config['default_dateformat'], '_') !== false)
		{
			$config->set('default_dateformat', $user->lang['default_dateformat']);
		}
		$sql = 'UPDATE ' . USERS_TABLE . ' SET user_dateformat = \'' . $config['default_dateformat'] . '\'
				WHERE user_dateformat ' . $db->sql_like_expression($db->get_any_char() . '_' . $db->get_any_char());
		$db->sql_query($sql);
	}

	private function restore_dateformat()
	{
		global $db;
		$config_text = $this->container->get('config_text');
		$config = $this->container->get('config');
		$default_dateformat_bk = $config_text->get('hijri_default_dateformat_bk');
		if (!empty($default_dateformat_bk))
		{
			$config->set('default_dateformat', $default_dateformat_bk);
			$config_text->set('hijri_default_dateformat_bk', '');
		}
		
		if (version_compare($config['hijri_version'], '2.2.0', '>='))
		{
			$sql = 'UPDATE ' . USERS_TABLE . ' SET user_dateformat = hijri_dateformat_bk WHERE hijri_dateformat_bk <> \'\' ';
			$db->sql_query($sql);
			$sql = 'UPDATE ' . USERS_TABLE . ' SET hijri_dateformat_bk = \'\' ';
			$db->sql_query($sql);
		}
	}
}
